package VMOMI::AutoStartAction;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
